Documentation
¶
Overview ¶
A Pulumi package for creating and managing Clickhouse Cloud resources
Index ¶
- type Provider
- type ProviderArgs
- type ProviderInput
- type ProviderOutput
- func (o ProviderOutput) ApiUrl() pulumi.StringPtrOutput
- func (ProviderOutput) ElementType() reflect.Type
- func (o ProviderOutput) OrganizationId() pulumi.StringPtrOutput
- func (o ProviderOutput) ToProviderOutput() ProviderOutput
- func (o ProviderOutput) ToProviderOutputWithContext(ctx context.Context) ProviderOutput
- func (o ProviderOutput) TokenKey() pulumi.StringPtrOutput
- func (o ProviderOutput) TokenSecret() pulumi.StringPtrOutput
- type Service
- type ServiceArgs
- type ServiceArray
- type ServiceArrayInput
- type ServiceArrayOutput
- type ServiceEndpoint
- type ServiceEndpointArgs
- type ServiceEndpointArray
- type ServiceEndpointArrayInput
- type ServiceEndpointArrayOutput
- func (ServiceEndpointArrayOutput) ElementType() reflect.Type
- func (o ServiceEndpointArrayOutput) Index(i pulumi.IntInput) ServiceEndpointOutput
- func (o ServiceEndpointArrayOutput) ToServiceEndpointArrayOutput() ServiceEndpointArrayOutput
- func (o ServiceEndpointArrayOutput) ToServiceEndpointArrayOutputWithContext(ctx context.Context) ServiceEndpointArrayOutput
- type ServiceEndpointInput
- type ServiceEndpointOutput
- func (ServiceEndpointOutput) ElementType() reflect.Type
- func (o ServiceEndpointOutput) Host() pulumi.StringPtrOutput
- func (o ServiceEndpointOutput) Port() pulumi.IntPtrOutput
- func (o ServiceEndpointOutput) Protocol() pulumi.StringPtrOutput
- func (o ServiceEndpointOutput) ToServiceEndpointOutput() ServiceEndpointOutput
- func (o ServiceEndpointOutput) ToServiceEndpointOutputWithContext(ctx context.Context) ServiceEndpointOutput
- type ServiceInput
- type ServiceIpAccess
- type ServiceIpAccessArgs
- type ServiceIpAccessArray
- type ServiceIpAccessArrayInput
- type ServiceIpAccessArrayOutput
- func (ServiceIpAccessArrayOutput) ElementType() reflect.Type
- func (o ServiceIpAccessArrayOutput) Index(i pulumi.IntInput) ServiceIpAccessOutput
- func (o ServiceIpAccessArrayOutput) ToServiceIpAccessArrayOutput() ServiceIpAccessArrayOutput
- func (o ServiceIpAccessArrayOutput) ToServiceIpAccessArrayOutputWithContext(ctx context.Context) ServiceIpAccessArrayOutput
- type ServiceIpAccessInput
- type ServiceIpAccessOutput
- func (o ServiceIpAccessOutput) Description() pulumi.StringPtrOutput
- func (ServiceIpAccessOutput) ElementType() reflect.Type
- func (o ServiceIpAccessOutput) Source() pulumi.StringOutput
- func (o ServiceIpAccessOutput) ToServiceIpAccessOutput() ServiceIpAccessOutput
- func (o ServiceIpAccessOutput) ToServiceIpAccessOutputWithContext(ctx context.Context) ServiceIpAccessOutput
- type ServiceMap
- type ServiceMapInput
- type ServiceMapOutput
- type ServiceOutput
- func (o ServiceOutput) CloudProvider() pulumi.StringOutput
- func (o ServiceOutput) DoubleSha1PasswordHash() pulumi.StringPtrOutput
- func (ServiceOutput) ElementType() reflect.Type
- func (o ServiceOutput) EncryptionAssumedRoleIdentifier() pulumi.StringPtrOutput
- func (o ServiceOutput) EncryptionKey() pulumi.StringPtrOutput
- func (o ServiceOutput) Endpoints() ServiceEndpointArrayOutput
- func (o ServiceOutput) IamRole() pulumi.StringOutput
- func (o ServiceOutput) IdleScaling() pulumi.BoolPtrOutput
- func (o ServiceOutput) IdleTimeoutMinutes() pulumi.IntPtrOutput
- func (o ServiceOutput) IpAccesses() ServiceIpAccessArrayOutput
- func (o ServiceOutput) MaxTotalMemoryGb() pulumi.IntPtrOutput
- func (o ServiceOutput) MinTotalMemoryGb() pulumi.IntPtrOutput
- func (o ServiceOutput) Name() pulumi.StringOutput
- func (o ServiceOutput) NumReplicas() pulumi.IntPtrOutput
- func (o ServiceOutput) Password() pulumi.StringPtrOutput
- func (o ServiceOutput) PasswordHash() pulumi.StringPtrOutput
- func (o ServiceOutput) PrivateEndpointConfig() ServicePrivateEndpointConfigOutputdeprecated
- func (o ServiceOutput) Region() pulumi.StringOutput
- func (o ServiceOutput) Tier() pulumi.StringOutput
- func (o ServiceOutput) ToServiceOutput() ServiceOutput
- func (o ServiceOutput) ToServiceOutputWithContext(ctx context.Context) ServiceOutput
- type ServicePrivateEndpointConfig
- type ServicePrivateEndpointConfigArgs
- func (ServicePrivateEndpointConfigArgs) ElementType() reflect.Type
- func (i ServicePrivateEndpointConfigArgs) ToServicePrivateEndpointConfigOutput() ServicePrivateEndpointConfigOutput
- func (i ServicePrivateEndpointConfigArgs) ToServicePrivateEndpointConfigOutputWithContext(ctx context.Context) ServicePrivateEndpointConfigOutput
- func (i ServicePrivateEndpointConfigArgs) ToServicePrivateEndpointConfigPtrOutput() ServicePrivateEndpointConfigPtrOutput
- func (i ServicePrivateEndpointConfigArgs) ToServicePrivateEndpointConfigPtrOutputWithContext(ctx context.Context) ServicePrivateEndpointConfigPtrOutput
- type ServicePrivateEndpointConfigInput
- type ServicePrivateEndpointConfigOutput
- func (ServicePrivateEndpointConfigOutput) ElementType() reflect.Type
- func (o ServicePrivateEndpointConfigOutput) EndpointServiceId() pulumi.StringPtrOutput
- func (o ServicePrivateEndpointConfigOutput) PrivateDnsHostname() pulumi.StringPtrOutput
- func (o ServicePrivateEndpointConfigOutput) ToServicePrivateEndpointConfigOutput() ServicePrivateEndpointConfigOutput
- func (o ServicePrivateEndpointConfigOutput) ToServicePrivateEndpointConfigOutputWithContext(ctx context.Context) ServicePrivateEndpointConfigOutput
- func (o ServicePrivateEndpointConfigOutput) ToServicePrivateEndpointConfigPtrOutput() ServicePrivateEndpointConfigPtrOutput
- func (o ServicePrivateEndpointConfigOutput) ToServicePrivateEndpointConfigPtrOutputWithContext(ctx context.Context) ServicePrivateEndpointConfigPtrOutput
- type ServicePrivateEndpointConfigPtrInput
- type ServicePrivateEndpointConfigPtrOutput
- func (o ServicePrivateEndpointConfigPtrOutput) Elem() ServicePrivateEndpointConfigOutput
- func (ServicePrivateEndpointConfigPtrOutput) ElementType() reflect.Type
- func (o ServicePrivateEndpointConfigPtrOutput) EndpointServiceId() pulumi.StringPtrOutput
- func (o ServicePrivateEndpointConfigPtrOutput) PrivateDnsHostname() pulumi.StringPtrOutput
- func (o ServicePrivateEndpointConfigPtrOutput) ToServicePrivateEndpointConfigPtrOutput() ServicePrivateEndpointConfigPtrOutput
- func (o ServicePrivateEndpointConfigPtrOutput) ToServicePrivateEndpointConfigPtrOutputWithContext(ctx context.Context) ServicePrivateEndpointConfigPtrOutput
- type ServiceState
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Provider ¶
type Provider struct {
pulumi.ProviderResourceState
// API URL of the ClickHouse OpenAPI the provider will interact with. Alternatively, can be configured using the
// `CLICKHOUSE_API_URL` environment variable. Only specify if you have a specific deployment of the ClickHouse OpenAPI you
// want to run against.
ApiUrl pulumi.StringPtrOutput `pulumi:"apiUrl"`
// ID of the organization the provider will create services under. Alternatively, can be configured using the
// `CLICKHOUSE_ORG_ID` environment variable.
OrganizationId pulumi.StringPtrOutput `pulumi:"organizationId"`
// Token key of the key/secret pair. Used to authenticate with OpenAPI. Alternatively, can be configured using the
// `CLICKHOUSE_TOKEN_KEY` environment variable.
TokenKey pulumi.StringPtrOutput `pulumi:"tokenKey"`
// Token secret of the key/secret pair. Used to authenticate with OpenAPI. Alternatively, can be configured using the
// `CLICKHOUSE_TOKEN_SECRET` environment variable.
TokenSecret pulumi.StringPtrOutput `pulumi:"tokenSecret"`
}
The provider type for the clickhouse package. By default, resources use package-wide configuration settings, however an explicit `Provider` instance may be created and passed during resource construction to achieve fine-grained programmatic control over provider settings. See the [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.
func NewProvider ¶
func NewProvider(ctx *pulumi.Context, name string, args *ProviderArgs, opts ...pulumi.ResourceOption) (*Provider, error)
NewProvider registers a new resource with the given unique name, arguments, and options.
func (*Provider) ElementType ¶
func (*Provider) ToProviderOutput ¶
func (i *Provider) ToProviderOutput() ProviderOutput
func (*Provider) ToProviderOutputWithContext ¶
func (i *Provider) ToProviderOutputWithContext(ctx context.Context) ProviderOutput
type ProviderArgs ¶
type ProviderArgs struct {
// API URL of the ClickHouse OpenAPI the provider will interact with. Alternatively, can be configured using the
// `CLICKHOUSE_API_URL` environment variable. Only specify if you have a specific deployment of the ClickHouse OpenAPI you
// want to run against.
ApiUrl pulumi.StringPtrInput
// ID of the organization the provider will create services under. Alternatively, can be configured using the
// `CLICKHOUSE_ORG_ID` environment variable.
OrganizationId pulumi.StringPtrInput
// Token key of the key/secret pair. Used to authenticate with OpenAPI. Alternatively, can be configured using the
// `CLICKHOUSE_TOKEN_KEY` environment variable.
TokenKey pulumi.StringPtrInput
// Token secret of the key/secret pair. Used to authenticate with OpenAPI. Alternatively, can be configured using the
// `CLICKHOUSE_TOKEN_SECRET` environment variable.
TokenSecret pulumi.StringPtrInput
}
The set of arguments for constructing a Provider resource.
func (ProviderArgs) ElementType ¶
func (ProviderArgs) ElementType() reflect.Type
type ProviderInput ¶
type ProviderInput interface {
pulumi.Input
ToProviderOutput() ProviderOutput
ToProviderOutputWithContext(ctx context.Context) ProviderOutput
}
type ProviderOutput ¶
type ProviderOutput struct{ *pulumi.OutputState }
func (ProviderOutput) ApiUrl ¶
func (o ProviderOutput) ApiUrl() pulumi.StringPtrOutput
API URL of the ClickHouse OpenAPI the provider will interact with. Alternatively, can be configured using the `CLICKHOUSE_API_URL` environment variable. Only specify if you have a specific deployment of the ClickHouse OpenAPI you want to run against.
func (ProviderOutput) ElementType ¶
func (ProviderOutput) ElementType() reflect.Type
func (ProviderOutput) OrganizationId ¶
func (o ProviderOutput) OrganizationId() pulumi.StringPtrOutput
ID of the organization the provider will create services under. Alternatively, can be configured using the `CLICKHOUSE_ORG_ID` environment variable.
func (ProviderOutput) ToProviderOutput ¶
func (o ProviderOutput) ToProviderOutput() ProviderOutput
func (ProviderOutput) ToProviderOutputWithContext ¶
func (o ProviderOutput) ToProviderOutputWithContext(ctx context.Context) ProviderOutput
func (ProviderOutput) TokenKey ¶
func (o ProviderOutput) TokenKey() pulumi.StringPtrOutput
Token key of the key/secret pair. Used to authenticate with OpenAPI. Alternatively, can be configured using the `CLICKHOUSE_TOKEN_KEY` environment variable.
func (ProviderOutput) TokenSecret ¶
func (o ProviderOutput) TokenSecret() pulumi.StringPtrOutput
Token secret of the key/secret pair. Used to authenticate with OpenAPI. Alternatively, can be configured using the `CLICKHOUSE_TOKEN_SECRET` environment variable.
type Service ¶
type Service struct {
pulumi.CustomResourceState
// Cloud provider ('aws', 'gcp', or 'azure') in which the service is deployed in.
CloudProvider pulumi.StringOutput `pulumi:"cloudProvider"`
// Double SHA1 hash of password for connecting with the MySQL protocol. Cannot be specified if `password` is specified.
DoubleSha1PasswordHash pulumi.StringPtrOutput `pulumi:"doubleSha1PasswordHash"`
// Custom role identifier arn
EncryptionAssumedRoleIdentifier pulumi.StringPtrOutput `pulumi:"encryptionAssumedRoleIdentifier"`
// Custom encryption key arn
EncryptionKey pulumi.StringPtrOutput `pulumi:"encryptionKey"`
// List of public endpoints.
Endpoints ServiceEndpointArrayOutput `pulumi:"endpoints"`
// IAM role used for accessing objects in s3.
IamRole pulumi.StringOutput `pulumi:"iamRole"`
// When set to true the service is allowed to scale down to zero when idle.
IdleScaling pulumi.BoolPtrOutput `pulumi:"idleScaling"`
// Set minimum idling timeout (in minutes). Must be greater than or equal to 5 minutes. Must be set if idleScaling is enabled
IdleTimeoutMinutes pulumi.IntPtrOutput `pulumi:"idleTimeoutMinutes"`
// List of IP addresses allowed to access the service.
IpAccesses ServiceIpAccessArrayOutput `pulumi:"ipAccesses"`
// Maximum total memory of all workers during auto-scaling in Gb. Available only for 'production' services. Must be a multiple of 12 and lower than 360 for non paid services or 720 for paid services.
MaxTotalMemoryGb pulumi.IntPtrOutput `pulumi:"maxTotalMemoryGb"`
// Minimum total memory of all workers during auto-scaling in Gb. Available only for 'production' services. Must be a multiple of 12 and greater than 24.
MinTotalMemoryGb pulumi.IntPtrOutput `pulumi:"minTotalMemoryGb"`
// User defined identifier for the service.
Name pulumi.StringOutput `pulumi:"name"`
// Number of replicas for the service. Available only for 'production' services. Must be between 3 and 20. Contact support to enable this feature.
NumReplicas pulumi.IntPtrOutput `pulumi:"numReplicas"`
// Password for the default user. One of either `password` or `passwordHash` must be specified.
Password pulumi.StringPtrOutput `pulumi:"password"`
// SHA256 hash of password for the default user. One of either `password` or `passwordHash` must be specified.
PasswordHash pulumi.StringPtrOutput `pulumi:"passwordHash"`
// Service config for private endpoints
//
// Deprecated: Please use the `PrivateEndpoint.getConfig` data source instead.
PrivateEndpointConfig ServicePrivateEndpointConfigOutput `pulumi:"privateEndpointConfig"`
// Region within the cloud provider in which the service is deployed in.
Region pulumi.StringOutput `pulumi:"region"`
// Tier of the service: 'development', 'production'. Production services scale, Development are fixed size.
Tier pulumi.StringOutput `pulumi:"tier"`
}
You can use the *clickhouse_service* resource to deploy ClickHouse cloud instances on supported cloud providers.
## Example Usage
```go package main
import (
"github.com/pulumi/pulumi/sdk/v3/go/pulumi" "github.com/pulumiverse/pulumi-clickhouse/sdk/go/clickhouse"
)
func main() {
pulumi.Run(func(ctx *pulumi.Context) error {
_, err := clickhouse.NewService(ctx, "service", &clickhouse.ServiceArgs{
CloudProvider: pulumi.String("aws"),
IdleScaling: pulumi.Bool(true),
IdleTimeoutMinutes: pulumi.Int(5),
IpAccesses: clickhouse.ServiceIpAccessArray{
&clickhouse.ServiceIpAccessArgs{
Description: pulumi.String("Test IP"),
Source: pulumi.String("192.168.2.63"),
},
},
MaxTotalMemoryGb: pulumi.Int(360),
MinTotalMemoryGb: pulumi.Int(24),
PasswordHash: pulumi.String("n4bQgYhMfWWaL+qgxVrQFaO/TxsrC4Is0V1sFbDwCgg="),
Region: pulumi.String("us-east-1"),
Tier: pulumi.String("production"),
})
if err != nil {
return err
}
return nil
})
}
```
## Import
Services can be imported by specifying the UUID.
```sh $ pulumi import clickhouse:index/service:Service example xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx ```
func GetService ¶
func GetService(ctx *pulumi.Context, name string, id pulumi.IDInput, state *ServiceState, opts ...pulumi.ResourceOption) (*Service, error)
GetService gets an existing Service resource's state with the given name, ID, and optional state properties that are used to uniquely qualify the lookup (nil if not required).
func NewService ¶
func NewService(ctx *pulumi.Context, name string, args *ServiceArgs, opts ...pulumi.ResourceOption) (*Service, error)
NewService registers a new resource with the given unique name, arguments, and options.
func (*Service) ElementType ¶
func (*Service) ToServiceOutput ¶
func (i *Service) ToServiceOutput() ServiceOutput
func (*Service) ToServiceOutputWithContext ¶
func (i *Service) ToServiceOutputWithContext(ctx context.Context) ServiceOutput
type ServiceArgs ¶
type ServiceArgs struct {
// Cloud provider ('aws', 'gcp', or 'azure') in which the service is deployed in.
CloudProvider pulumi.StringInput
// Double SHA1 hash of password for connecting with the MySQL protocol. Cannot be specified if `password` is specified.
DoubleSha1PasswordHash pulumi.StringPtrInput
// Custom role identifier arn
EncryptionAssumedRoleIdentifier pulumi.StringPtrInput
// Custom encryption key arn
EncryptionKey pulumi.StringPtrInput
// When set to true the service is allowed to scale down to zero when idle.
IdleScaling pulumi.BoolPtrInput
// Set minimum idling timeout (in minutes). Must be greater than or equal to 5 minutes. Must be set if idleScaling is enabled
IdleTimeoutMinutes pulumi.IntPtrInput
// List of IP addresses allowed to access the service.
IpAccesses ServiceIpAccessArrayInput
// Maximum total memory of all workers during auto-scaling in Gb. Available only for 'production' services. Must be a multiple of 12 and lower than 360 for non paid services or 720 for paid services.
MaxTotalMemoryGb pulumi.IntPtrInput
// Minimum total memory of all workers during auto-scaling in Gb. Available only for 'production' services. Must be a multiple of 12 and greater than 24.
MinTotalMemoryGb pulumi.IntPtrInput
// User defined identifier for the service.
Name pulumi.StringPtrInput
// Number of replicas for the service. Available only for 'production' services. Must be between 3 and 20. Contact support to enable this feature.
NumReplicas pulumi.IntPtrInput
// Password for the default user. One of either `password` or `passwordHash` must be specified.
Password pulumi.StringPtrInput
// SHA256 hash of password for the default user. One of either `password` or `passwordHash` must be specified.
PasswordHash pulumi.StringPtrInput
// Region within the cloud provider in which the service is deployed in.
Region pulumi.StringInput
// Tier of the service: 'development', 'production'. Production services scale, Development are fixed size.
Tier pulumi.StringInput
}
The set of arguments for constructing a Service resource.
func (ServiceArgs) ElementType ¶
func (ServiceArgs) ElementType() reflect.Type
type ServiceArray ¶
type ServiceArray []ServiceInput
func (ServiceArray) ElementType ¶
func (ServiceArray) ElementType() reflect.Type
func (ServiceArray) ToServiceArrayOutput ¶
func (i ServiceArray) ToServiceArrayOutput() ServiceArrayOutput
func (ServiceArray) ToServiceArrayOutputWithContext ¶
func (i ServiceArray) ToServiceArrayOutputWithContext(ctx context.Context) ServiceArrayOutput
type ServiceArrayInput ¶
type ServiceArrayInput interface {
pulumi.Input
ToServiceArrayOutput() ServiceArrayOutput
ToServiceArrayOutputWithContext(context.Context) ServiceArrayOutput
}
ServiceArrayInput is an input type that accepts ServiceArray and ServiceArrayOutput values. You can construct a concrete instance of `ServiceArrayInput` via:
ServiceArray{ ServiceArgs{...} }
type ServiceArrayOutput ¶
type ServiceArrayOutput struct{ *pulumi.OutputState }
func (ServiceArrayOutput) ElementType ¶
func (ServiceArrayOutput) ElementType() reflect.Type
func (ServiceArrayOutput) Index ¶
func (o ServiceArrayOutput) Index(i pulumi.IntInput) ServiceOutput
func (ServiceArrayOutput) ToServiceArrayOutput ¶
func (o ServiceArrayOutput) ToServiceArrayOutput() ServiceArrayOutput
func (ServiceArrayOutput) ToServiceArrayOutputWithContext ¶
func (o ServiceArrayOutput) ToServiceArrayOutputWithContext(ctx context.Context) ServiceArrayOutput
type ServiceEndpoint ¶
type ServiceEndpointArgs ¶
type ServiceEndpointArgs struct {
// Endpoint host.
Host pulumi.StringPtrInput `pulumi:"host"`
// Endpoint port.
Port pulumi.IntPtrInput `pulumi:"port"`
// Endpoint protocol: https or nativesecure
Protocol pulumi.StringPtrInput `pulumi:"protocol"`
}
func (ServiceEndpointArgs) ElementType ¶
func (ServiceEndpointArgs) ElementType() reflect.Type
func (ServiceEndpointArgs) ToServiceEndpointOutput ¶
func (i ServiceEndpointArgs) ToServiceEndpointOutput() ServiceEndpointOutput
func (ServiceEndpointArgs) ToServiceEndpointOutputWithContext ¶
func (i ServiceEndpointArgs) ToServiceEndpointOutputWithContext(ctx context.Context) ServiceEndpointOutput
type ServiceEndpointArray ¶
type ServiceEndpointArray []ServiceEndpointInput
func (ServiceEndpointArray) ElementType ¶
func (ServiceEndpointArray) ElementType() reflect.Type
func (ServiceEndpointArray) ToServiceEndpointArrayOutput ¶
func (i ServiceEndpointArray) ToServiceEndpointArrayOutput() ServiceEndpointArrayOutput
func (ServiceEndpointArray) ToServiceEndpointArrayOutputWithContext ¶
func (i ServiceEndpointArray) ToServiceEndpointArrayOutputWithContext(ctx context.Context) ServiceEndpointArrayOutput
type ServiceEndpointArrayInput ¶
type ServiceEndpointArrayInput interface {
pulumi.Input
ToServiceEndpointArrayOutput() ServiceEndpointArrayOutput
ToServiceEndpointArrayOutputWithContext(context.Context) ServiceEndpointArrayOutput
}
ServiceEndpointArrayInput is an input type that accepts ServiceEndpointArray and ServiceEndpointArrayOutput values. You can construct a concrete instance of `ServiceEndpointArrayInput` via:
ServiceEndpointArray{ ServiceEndpointArgs{...} }
type ServiceEndpointArrayOutput ¶
type ServiceEndpointArrayOutput struct{ *pulumi.OutputState }
func (ServiceEndpointArrayOutput) ElementType ¶
func (ServiceEndpointArrayOutput) ElementType() reflect.Type
func (ServiceEndpointArrayOutput) Index ¶
func (o ServiceEndpointArrayOutput) Index(i pulumi.IntInput) ServiceEndpointOutput
func (ServiceEndpointArrayOutput) ToServiceEndpointArrayOutput ¶
func (o ServiceEndpointArrayOutput) ToServiceEndpointArrayOutput() ServiceEndpointArrayOutput
func (ServiceEndpointArrayOutput) ToServiceEndpointArrayOutputWithContext ¶
func (o ServiceEndpointArrayOutput) ToServiceEndpointArrayOutputWithContext(ctx context.Context) ServiceEndpointArrayOutput
type ServiceEndpointInput ¶
type ServiceEndpointInput interface {
pulumi.Input
ToServiceEndpointOutput() ServiceEndpointOutput
ToServiceEndpointOutputWithContext(context.Context) ServiceEndpointOutput
}
ServiceEndpointInput is an input type that accepts ServiceEndpointArgs and ServiceEndpointOutput values. You can construct a concrete instance of `ServiceEndpointInput` via:
ServiceEndpointArgs{...}
type ServiceEndpointOutput ¶
type ServiceEndpointOutput struct{ *pulumi.OutputState }
func (ServiceEndpointOutput) ElementType ¶
func (ServiceEndpointOutput) ElementType() reflect.Type
func (ServiceEndpointOutput) Host ¶
func (o ServiceEndpointOutput) Host() pulumi.StringPtrOutput
Endpoint host.
func (ServiceEndpointOutput) Port ¶
func (o ServiceEndpointOutput) Port() pulumi.IntPtrOutput
Endpoint port.
func (ServiceEndpointOutput) Protocol ¶
func (o ServiceEndpointOutput) Protocol() pulumi.StringPtrOutput
Endpoint protocol: https or nativesecure
func (ServiceEndpointOutput) ToServiceEndpointOutput ¶
func (o ServiceEndpointOutput) ToServiceEndpointOutput() ServiceEndpointOutput
func (ServiceEndpointOutput) ToServiceEndpointOutputWithContext ¶
func (o ServiceEndpointOutput) ToServiceEndpointOutputWithContext(ctx context.Context) ServiceEndpointOutput
type ServiceInput ¶
type ServiceInput interface {
pulumi.Input
ToServiceOutput() ServiceOutput
ToServiceOutputWithContext(ctx context.Context) ServiceOutput
}
type ServiceIpAccess ¶
type ServiceIpAccessArgs ¶
type ServiceIpAccessArgs struct {
// Description of the IP address.
Description pulumi.StringPtrInput `pulumi:"description"`
// IP address allowed to access the service. In case you want to set the ipAccess to anywhere you should set source to 0.0.0.0/0
Source pulumi.StringInput `pulumi:"source"`
}
func (ServiceIpAccessArgs) ElementType ¶
func (ServiceIpAccessArgs) ElementType() reflect.Type
func (ServiceIpAccessArgs) ToServiceIpAccessOutput ¶
func (i ServiceIpAccessArgs) ToServiceIpAccessOutput() ServiceIpAccessOutput
func (ServiceIpAccessArgs) ToServiceIpAccessOutputWithContext ¶
func (i ServiceIpAccessArgs) ToServiceIpAccessOutputWithContext(ctx context.Context) ServiceIpAccessOutput
type ServiceIpAccessArray ¶
type ServiceIpAccessArray []ServiceIpAccessInput
func (ServiceIpAccessArray) ElementType ¶
func (ServiceIpAccessArray) ElementType() reflect.Type
func (ServiceIpAccessArray) ToServiceIpAccessArrayOutput ¶
func (i ServiceIpAccessArray) ToServiceIpAccessArrayOutput() ServiceIpAccessArrayOutput
func (ServiceIpAccessArray) ToServiceIpAccessArrayOutputWithContext ¶
func (i ServiceIpAccessArray) ToServiceIpAccessArrayOutputWithContext(ctx context.Context) ServiceIpAccessArrayOutput
type ServiceIpAccessArrayInput ¶
type ServiceIpAccessArrayInput interface {
pulumi.Input
ToServiceIpAccessArrayOutput() ServiceIpAccessArrayOutput
ToServiceIpAccessArrayOutputWithContext(context.Context) ServiceIpAccessArrayOutput
}
ServiceIpAccessArrayInput is an input type that accepts ServiceIpAccessArray and ServiceIpAccessArrayOutput values. You can construct a concrete instance of `ServiceIpAccessArrayInput` via:
ServiceIpAccessArray{ ServiceIpAccessArgs{...} }
type ServiceIpAccessArrayOutput ¶
type ServiceIpAccessArrayOutput struct{ *pulumi.OutputState }
func (ServiceIpAccessArrayOutput) ElementType ¶
func (ServiceIpAccessArrayOutput) ElementType() reflect.Type
func (ServiceIpAccessArrayOutput) Index ¶
func (o ServiceIpAccessArrayOutput) Index(i pulumi.IntInput) ServiceIpAccessOutput
func (ServiceIpAccessArrayOutput) ToServiceIpAccessArrayOutput ¶
func (o ServiceIpAccessArrayOutput) ToServiceIpAccessArrayOutput() ServiceIpAccessArrayOutput
func (ServiceIpAccessArrayOutput) ToServiceIpAccessArrayOutputWithContext ¶
func (o ServiceIpAccessArrayOutput) ToServiceIpAccessArrayOutputWithContext(ctx context.Context) ServiceIpAccessArrayOutput
type ServiceIpAccessInput ¶
type ServiceIpAccessInput interface {
pulumi.Input
ToServiceIpAccessOutput() ServiceIpAccessOutput
ToServiceIpAccessOutputWithContext(context.Context) ServiceIpAccessOutput
}
ServiceIpAccessInput is an input type that accepts ServiceIpAccessArgs and ServiceIpAccessOutput values. You can construct a concrete instance of `ServiceIpAccessInput` via:
ServiceIpAccessArgs{...}
type ServiceIpAccessOutput ¶
type ServiceIpAccessOutput struct{ *pulumi.OutputState }
func (ServiceIpAccessOutput) Description ¶
func (o ServiceIpAccessOutput) Description() pulumi.StringPtrOutput
Description of the IP address.
func (ServiceIpAccessOutput) ElementType ¶
func (ServiceIpAccessOutput) ElementType() reflect.Type
func (ServiceIpAccessOutput) Source ¶
func (o ServiceIpAccessOutput) Source() pulumi.StringOutput
IP address allowed to access the service. In case you want to set the ipAccess to anywhere you should set source to 0.0.0.0/0
func (ServiceIpAccessOutput) ToServiceIpAccessOutput ¶
func (o ServiceIpAccessOutput) ToServiceIpAccessOutput() ServiceIpAccessOutput
func (ServiceIpAccessOutput) ToServiceIpAccessOutputWithContext ¶
func (o ServiceIpAccessOutput) ToServiceIpAccessOutputWithContext(ctx context.Context) ServiceIpAccessOutput
type ServiceMap ¶
type ServiceMap map[string]ServiceInput
func (ServiceMap) ElementType ¶
func (ServiceMap) ElementType() reflect.Type
func (ServiceMap) ToServiceMapOutput ¶
func (i ServiceMap) ToServiceMapOutput() ServiceMapOutput
func (ServiceMap) ToServiceMapOutputWithContext ¶
func (i ServiceMap) ToServiceMapOutputWithContext(ctx context.Context) ServiceMapOutput
type ServiceMapInput ¶
type ServiceMapInput interface {
pulumi.Input
ToServiceMapOutput() ServiceMapOutput
ToServiceMapOutputWithContext(context.Context) ServiceMapOutput
}
ServiceMapInput is an input type that accepts ServiceMap and ServiceMapOutput values. You can construct a concrete instance of `ServiceMapInput` via:
ServiceMap{ "key": ServiceArgs{...} }
type ServiceMapOutput ¶
type ServiceMapOutput struct{ *pulumi.OutputState }
func (ServiceMapOutput) ElementType ¶
func (ServiceMapOutput) ElementType() reflect.Type
func (ServiceMapOutput) MapIndex ¶
func (o ServiceMapOutput) MapIndex(k pulumi.StringInput) ServiceOutput
func (ServiceMapOutput) ToServiceMapOutput ¶
func (o ServiceMapOutput) ToServiceMapOutput() ServiceMapOutput
func (ServiceMapOutput) ToServiceMapOutputWithContext ¶
func (o ServiceMapOutput) ToServiceMapOutputWithContext(ctx context.Context) ServiceMapOutput
type ServiceOutput ¶
type ServiceOutput struct{ *pulumi.OutputState }
func (ServiceOutput) CloudProvider ¶
func (o ServiceOutput) CloudProvider() pulumi.StringOutput
Cloud provider ('aws', 'gcp', or 'azure') in which the service is deployed in.
func (ServiceOutput) DoubleSha1PasswordHash ¶
func (o ServiceOutput) DoubleSha1PasswordHash() pulumi.StringPtrOutput
Double SHA1 hash of password for connecting with the MySQL protocol. Cannot be specified if `password` is specified.
func (ServiceOutput) ElementType ¶
func (ServiceOutput) ElementType() reflect.Type
func (ServiceOutput) EncryptionAssumedRoleIdentifier ¶
func (o ServiceOutput) EncryptionAssumedRoleIdentifier() pulumi.StringPtrOutput
Custom role identifier arn
func (ServiceOutput) EncryptionKey ¶
func (o ServiceOutput) EncryptionKey() pulumi.StringPtrOutput
Custom encryption key arn
func (ServiceOutput) Endpoints ¶
func (o ServiceOutput) Endpoints() ServiceEndpointArrayOutput
List of public endpoints.
func (ServiceOutput) IamRole ¶
func (o ServiceOutput) IamRole() pulumi.StringOutput
IAM role used for accessing objects in s3.
func (ServiceOutput) IdleScaling ¶
func (o ServiceOutput) IdleScaling() pulumi.BoolPtrOutput
When set to true the service is allowed to scale down to zero when idle.
func (ServiceOutput) IdleTimeoutMinutes ¶
func (o ServiceOutput) IdleTimeoutMinutes() pulumi.IntPtrOutput
Set minimum idling timeout (in minutes). Must be greater than or equal to 5 minutes. Must be set if idleScaling is enabled
func (ServiceOutput) IpAccesses ¶
func (o ServiceOutput) IpAccesses() ServiceIpAccessArrayOutput
List of IP addresses allowed to access the service.
func (ServiceOutput) MaxTotalMemoryGb ¶
func (o ServiceOutput) MaxTotalMemoryGb() pulumi.IntPtrOutput
Maximum total memory of all workers during auto-scaling in Gb. Available only for 'production' services. Must be a multiple of 12 and lower than 360 for non paid services or 720 for paid services.
func (ServiceOutput) MinTotalMemoryGb ¶
func (o ServiceOutput) MinTotalMemoryGb() pulumi.IntPtrOutput
Minimum total memory of all workers during auto-scaling in Gb. Available only for 'production' services. Must be a multiple of 12 and greater than 24.
func (ServiceOutput) Name ¶
func (o ServiceOutput) Name() pulumi.StringOutput
User defined identifier for the service.
func (ServiceOutput) NumReplicas ¶
func (o ServiceOutput) NumReplicas() pulumi.IntPtrOutput
Number of replicas for the service. Available only for 'production' services. Must be between 3 and 20. Contact support to enable this feature.
func (ServiceOutput) Password ¶
func (o ServiceOutput) Password() pulumi.StringPtrOutput
Password for the default user. One of either `password` or `passwordHash` must be specified.
func (ServiceOutput) PasswordHash ¶
func (o ServiceOutput) PasswordHash() pulumi.StringPtrOutput
SHA256 hash of password for the default user. One of either `password` or `passwordHash` must be specified.
func (ServiceOutput) PrivateEndpointConfig
deprecated
func (o ServiceOutput) PrivateEndpointConfig() ServicePrivateEndpointConfigOutput
Service config for private endpoints
Deprecated: Please use the `PrivateEndpoint.getConfig` data source instead.
func (ServiceOutput) Region ¶
func (o ServiceOutput) Region() pulumi.StringOutput
Region within the cloud provider in which the service is deployed in.
func (ServiceOutput) Tier ¶
func (o ServiceOutput) Tier() pulumi.StringOutput
Tier of the service: 'development', 'production'. Production services scale, Development are fixed size.
func (ServiceOutput) ToServiceOutput ¶
func (o ServiceOutput) ToServiceOutput() ServiceOutput
func (ServiceOutput) ToServiceOutputWithContext ¶
func (o ServiceOutput) ToServiceOutputWithContext(ctx context.Context) ServiceOutput
type ServicePrivateEndpointConfig ¶
type ServicePrivateEndpointConfig struct {
// Unique identifier of the interface endpoint you created in your VPC with the AWS(Service Name) or GCP(Target Service) resource
EndpointServiceId *string `pulumi:"endpointServiceId"`
// Private DNS Hostname of the VPC you created
PrivateDnsHostname *string `pulumi:"privateDnsHostname"`
}
type ServicePrivateEndpointConfigArgs ¶
type ServicePrivateEndpointConfigArgs struct {
// Unique identifier of the interface endpoint you created in your VPC with the AWS(Service Name) or GCP(Target Service) resource
EndpointServiceId pulumi.StringPtrInput `pulumi:"endpointServiceId"`
// Private DNS Hostname of the VPC you created
PrivateDnsHostname pulumi.StringPtrInput `pulumi:"privateDnsHostname"`
}
func (ServicePrivateEndpointConfigArgs) ElementType ¶
func (ServicePrivateEndpointConfigArgs) ElementType() reflect.Type
func (ServicePrivateEndpointConfigArgs) ToServicePrivateEndpointConfigOutput ¶
func (i ServicePrivateEndpointConfigArgs) ToServicePrivateEndpointConfigOutput() ServicePrivateEndpointConfigOutput
func (ServicePrivateEndpointConfigArgs) ToServicePrivateEndpointConfigOutputWithContext ¶
func (i ServicePrivateEndpointConfigArgs) ToServicePrivateEndpointConfigOutputWithContext(ctx context.Context) ServicePrivateEndpointConfigOutput
func (ServicePrivateEndpointConfigArgs) ToServicePrivateEndpointConfigPtrOutput ¶
func (i ServicePrivateEndpointConfigArgs) ToServicePrivateEndpointConfigPtrOutput() ServicePrivateEndpointConfigPtrOutput
func (ServicePrivateEndpointConfigArgs) ToServicePrivateEndpointConfigPtrOutputWithContext ¶
func (i ServicePrivateEndpointConfigArgs) ToServicePrivateEndpointConfigPtrOutputWithContext(ctx context.Context) ServicePrivateEndpointConfigPtrOutput
type ServicePrivateEndpointConfigInput ¶
type ServicePrivateEndpointConfigInput interface {
pulumi.Input
ToServicePrivateEndpointConfigOutput() ServicePrivateEndpointConfigOutput
ToServicePrivateEndpointConfigOutputWithContext(context.Context) ServicePrivateEndpointConfigOutput
}
ServicePrivateEndpointConfigInput is an input type that accepts ServicePrivateEndpointConfigArgs and ServicePrivateEndpointConfigOutput values. You can construct a concrete instance of `ServicePrivateEndpointConfigInput` via:
ServicePrivateEndpointConfigArgs{...}
type ServicePrivateEndpointConfigOutput ¶
type ServicePrivateEndpointConfigOutput struct{ *pulumi.OutputState }
func (ServicePrivateEndpointConfigOutput) ElementType ¶
func (ServicePrivateEndpointConfigOutput) ElementType() reflect.Type
func (ServicePrivateEndpointConfigOutput) EndpointServiceId ¶
func (o ServicePrivateEndpointConfigOutput) EndpointServiceId() pulumi.StringPtrOutput
Unique identifier of the interface endpoint you created in your VPC with the AWS(Service Name) or GCP(Target Service) resource
func (ServicePrivateEndpointConfigOutput) PrivateDnsHostname ¶
func (o ServicePrivateEndpointConfigOutput) PrivateDnsHostname() pulumi.StringPtrOutput
Private DNS Hostname of the VPC you created
func (ServicePrivateEndpointConfigOutput) ToServicePrivateEndpointConfigOutput ¶
func (o ServicePrivateEndpointConfigOutput) ToServicePrivateEndpointConfigOutput() ServicePrivateEndpointConfigOutput
func (ServicePrivateEndpointConfigOutput) ToServicePrivateEndpointConfigOutputWithContext ¶
func (o ServicePrivateEndpointConfigOutput) ToServicePrivateEndpointConfigOutputWithContext(ctx context.Context) ServicePrivateEndpointConfigOutput
func (ServicePrivateEndpointConfigOutput) ToServicePrivateEndpointConfigPtrOutput ¶
func (o ServicePrivateEndpointConfigOutput) ToServicePrivateEndpointConfigPtrOutput() ServicePrivateEndpointConfigPtrOutput
func (ServicePrivateEndpointConfigOutput) ToServicePrivateEndpointConfigPtrOutputWithContext ¶
func (o ServicePrivateEndpointConfigOutput) ToServicePrivateEndpointConfigPtrOutputWithContext(ctx context.Context) ServicePrivateEndpointConfigPtrOutput
type ServicePrivateEndpointConfigPtrInput ¶
type ServicePrivateEndpointConfigPtrInput interface {
pulumi.Input
ToServicePrivateEndpointConfigPtrOutput() ServicePrivateEndpointConfigPtrOutput
ToServicePrivateEndpointConfigPtrOutputWithContext(context.Context) ServicePrivateEndpointConfigPtrOutput
}
ServicePrivateEndpointConfigPtrInput is an input type that accepts ServicePrivateEndpointConfigArgs, ServicePrivateEndpointConfigPtr and ServicePrivateEndpointConfigPtrOutput values. You can construct a concrete instance of `ServicePrivateEndpointConfigPtrInput` via:
ServicePrivateEndpointConfigArgs{...}
or:
nil
func ServicePrivateEndpointConfigPtr ¶
func ServicePrivateEndpointConfigPtr(v *ServicePrivateEndpointConfigArgs) ServicePrivateEndpointConfigPtrInput
type ServicePrivateEndpointConfigPtrOutput ¶
type ServicePrivateEndpointConfigPtrOutput struct{ *pulumi.OutputState }
func (ServicePrivateEndpointConfigPtrOutput) ElementType ¶
func (ServicePrivateEndpointConfigPtrOutput) ElementType() reflect.Type
func (ServicePrivateEndpointConfigPtrOutput) EndpointServiceId ¶
func (o ServicePrivateEndpointConfigPtrOutput) EndpointServiceId() pulumi.StringPtrOutput
Unique identifier of the interface endpoint you created in your VPC with the AWS(Service Name) or GCP(Target Service) resource
func (ServicePrivateEndpointConfigPtrOutput) PrivateDnsHostname ¶
func (o ServicePrivateEndpointConfigPtrOutput) PrivateDnsHostname() pulumi.StringPtrOutput
Private DNS Hostname of the VPC you created
func (ServicePrivateEndpointConfigPtrOutput) ToServicePrivateEndpointConfigPtrOutput ¶
func (o ServicePrivateEndpointConfigPtrOutput) ToServicePrivateEndpointConfigPtrOutput() ServicePrivateEndpointConfigPtrOutput
func (ServicePrivateEndpointConfigPtrOutput) ToServicePrivateEndpointConfigPtrOutputWithContext ¶
func (o ServicePrivateEndpointConfigPtrOutput) ToServicePrivateEndpointConfigPtrOutputWithContext(ctx context.Context) ServicePrivateEndpointConfigPtrOutput
type ServiceState ¶
type ServiceState struct {
// Cloud provider ('aws', 'gcp', or 'azure') in which the service is deployed in.
CloudProvider pulumi.StringPtrInput
// Double SHA1 hash of password for connecting with the MySQL protocol. Cannot be specified if `password` is specified.
DoubleSha1PasswordHash pulumi.StringPtrInput
// Custom role identifier arn
EncryptionAssumedRoleIdentifier pulumi.StringPtrInput
// Custom encryption key arn
EncryptionKey pulumi.StringPtrInput
// List of public endpoints.
Endpoints ServiceEndpointArrayInput
// IAM role used for accessing objects in s3.
IamRole pulumi.StringPtrInput
// When set to true the service is allowed to scale down to zero when idle.
IdleScaling pulumi.BoolPtrInput
// Set minimum idling timeout (in minutes). Must be greater than or equal to 5 minutes. Must be set if idleScaling is enabled
IdleTimeoutMinutes pulumi.IntPtrInput
// List of IP addresses allowed to access the service.
IpAccesses ServiceIpAccessArrayInput
// Maximum total memory of all workers during auto-scaling in Gb. Available only for 'production' services. Must be a multiple of 12 and lower than 360 for non paid services or 720 for paid services.
MaxTotalMemoryGb pulumi.IntPtrInput
// Minimum total memory of all workers during auto-scaling in Gb. Available only for 'production' services. Must be a multiple of 12 and greater than 24.
MinTotalMemoryGb pulumi.IntPtrInput
// User defined identifier for the service.
Name pulumi.StringPtrInput
// Number of replicas for the service. Available only for 'production' services. Must be between 3 and 20. Contact support to enable this feature.
NumReplicas pulumi.IntPtrInput
// Password for the default user. One of either `password` or `passwordHash` must be specified.
Password pulumi.StringPtrInput
// SHA256 hash of password for the default user. One of either `password` or `passwordHash` must be specified.
PasswordHash pulumi.StringPtrInput
// Service config for private endpoints
//
// Deprecated: Please use the `PrivateEndpoint.getConfig` data source instead.
PrivateEndpointConfig ServicePrivateEndpointConfigPtrInput
// Region within the cloud provider in which the service is deployed in.
Region pulumi.StringPtrInput
// Tier of the service: 'development', 'production'. Production services scale, Development are fixed size.
Tier pulumi.StringPtrInput
}
func (ServiceState) ElementType ¶
func (ServiceState) ElementType() reflect.Type